==> subtitlecomposer-0.4.1.tar.bz2: subtitlecomposer-0.4.1/src/formats/tmplayer/tmplayeroutputformat.h <==
#ifndef TMPLAYEROUTPUTFORMAT_H
#define TMPLAYEROUTPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <outputformat.h>
#include <qstring.h>

namespace SubtitleComposer
{
	class TMPlayerOutputFormat : public OutputFormat
	{
		friend class FormatsManager;

		public:

			~TMPlayerOutputFormat() {}

			virtual QString dumpSubtitles( const Subtitle& subtitle, bool primary ) const
			{
				QString builder;
				QString ret;

				for ( SubtitleIterator it( subtitle ); it.current(); ++it )
				{
					const SubtitleLine* line = it.current();

					Time showTime = line->showTime();
					ret += builder.sprintf(
						m_timeFormat,
						showTime.hours(),
						showTime.minutes(),
						showTime.seconds()
					);

					ret += (primary ? line->primaryText() : line->secondaryText()).replace( "\n", "|" );
					ret += "\n";

					// We behave like Subtitle Composer here: to compensate for the lack of hide time
					// indication provisions in the format we add an empty line with the hide time.
					Time hideTime = line->hideTime();
					ret += builder.sprintf(
						m_timeFormat,
						hideTime.hours(),
						hideTime.minutes(),
						hideTime.seconds()
					);

					ret += "\n";
				}

				return ret;
			}

		protected:

			TMPlayerOutputFormat():
				OutputFormat( "TMPlayer", "txt" ),
				m_timeFormat( "%02d:%02d:%02d:" )
			{
			}

			TMPlayerOutputFormat( const QString& name, const QStringList& extensions, const QString& timeFormat ):
				OutputFormat( name, extensions ),
				m_timeFormat( timeFormat )
			{
			}

			const QString m_timeFormat;
	};

	class TMPlayerPlusOutputFormat : public TMPlayerOutputFormat
	{
		friend class FormatsManager;

		protected:

			TMPlayerPlusOutputFormat():
				TMPlayerOutputFormat( "TMPlayer+", "txt", "%02d:%02d:%02d=" )
			{
			}
	};
}

#endif

==> subtitlecomposer-0.4.2.tar.bz2: subtitlecomposer-0.4.2/src/formats/tmplayer/tmplayeroutputformat.h <==
#ifndef TMPLAYEROUTPUTFORMAT_H
#define TMPLAYEROUTPUTFORMAT_H

/***************************************************************************
 *   Copyright (C) 2007-2008 by Sergio Pistone                             *
 *   sergio_pistone@yahoo.com.ar                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/


#ifdef HAVE_CONFIG_H
	#include <config.h>
#endif

#include <outputformat.h>

namespace SubtitleComposer
{
	class TMPlayerOutputFormat : public OutputFormat
	{
		friend class FormatManager;

		public:

			~TMPlayerOutputFormat() {}

			virtual QString dumpSubtitles( const Subtitle& subtitle, bool primary ) const
			{
				QString builder;
				QString ret;

				for ( SubtitleIterator it( subtitle ); it.current(); ++it )
				{
					const SubtitleLine* line = it.current();

					Time showTime = line->showTime();
					ret += builder.sprintf(
						m_timeFormat,
						showTime.hours(),
						showTime.minutes(),
						showTime.seconds()
					);

					const SString& text = primary ? line->primaryText() : line->secondaryText();
					ret += text.string().replace( "\n", "|" );
					ret += "\n";

					// We behave like Subtitle Workshop here: to compensate for the lack of hide time
					// indication provisions in the format we add an empty line with the hide time.
					Time hideTime = line->hideTime();
					ret += builder.sprintf(
						m_timeFormat,
						hideTime.hours(),
						hideTime.minutes(),
						hideTime.seconds()
					);

					ret += "\n";
				}

				return ret;
			}

		protected:

			TMPlayerOutputFormat():
				OutputFormat( "TMPlayer", "txt" ),
				m_timeFormat( "%02d:%02d:%02d:" )
			{
			}

			TMPlayerOutputFormat( const QString& name, const QStringList& extensions, const QString& timeFormat ):
				OutputFormat( name, extensions ),
				m_timeFormat( timeFormat )
			{
			}

			const QString m_timeFormat;
	};

	class TMPlayerPlusOutputFormat : public TMPlayerOutputFormat
	{
		friend class FormatManager;

		protected:

			TMPlayerPlusOutputFormat():
				TMPlayerOutputFormat( "TMPlayer+", "txt", "%02d:%02d:%02d=" )
			{
			}
	};
}

#endif
